@@ -9,7 +9,7 @@ use Moo;
 extends q(Data::Validation::Constraints);
 
 EXCEPTION_CLASS->add_exception( 'ValidEmail', {
-   parents => [ 'Constraint' ],
+   parents => [ 'InvalidParameter' ],
    error   => 'Parameter [_1] value [_2] is not a valid email address' } );
 
 sub validate {
